@@ -12,10 +12,18 @@ use structopt::StructOpt;
 pub enum Args {
     #[structopt(about = "deploy an shuttle project")]
     Deploy(DeployArgs),
-    #[structopt(about = "view the status of an shuttle deployment")]
+    #[structopt(about = "view the status of an shuttle project")]
     Status,
-    #[structopt(about = "view the status of an shuttle deployment")]
+    #[structopt(about = "delete the latest deployment for a shuttle project")]
     Delete,
+    #[structopt(about = "create user credentials for the shuttle platform")]
+    Auth(AuthArgs),
+}
+
+#[derive(StructOpt)]
+pub struct AuthArgs {
+    #[structopt(about = "the desired username for the shuttle platform")]
+    pub username: String,
 }
 
 #[derive(StructOpt)]
